@@ -5,7 +5,6 @@
 
   se            <- TRUE
   interpolation <- TRUE
-  #options(warn=0)
 
   X <- object$X
   #collapse X
@@ -48,7 +47,8 @@
     gmemb1  <- gmemb
   }
 
-  mt_vek <- apply(X, 2L, max, na.rm = TRUE)   #number of categories - 1 for each item
+  #mt_vek <- apply(X, 2L, max, na.rm = TRUE)   #number of categories - 1 for each item
+  mt_vek <- apply(object$X, 2L, max, na.rm = TRUE)   ## FIX: to be tested
   mt_ind <- rep(1L:length(mt_vek), mt_vek)    #index i for items
 
   indvec <- NULL                              #establish matrix with unique raw scores
@@ -57,10 +57,9 @@
     collapse.vec <- which(!duplicated(rowSums(rbind(X[gmemb==i,]), na.rm = TRUE)))
     indvec       <- c(indvec, gmemb.ind[collapse.vec])
   }
-  #for (i in unique(gmemb)) indvec <- c(indvec,!duplicated(rowSums(rbind(X[gmemb==i,]),na.rm = TRUE)))
-
+  
   indvec <- sort(indvec)
-  X      <- X[indvec,]     #collapsing X
+  X <- X[indvec,]     #collapsing X
 
   beta.all <- object$betapar
 
@@ -79,15 +78,11 @@
 
   X01 <- object$X01
   if(length(pers.exe) > 0L) X01 <- X01[-pers.exe,]   #if persons excluded due to 0/full response
-
   X01           <- X01[indvec,]                      #collapsed version
   gmemb         <- gmemb[indvec]                     #collapsed version
   rownames(X01) <- rownames(X)
-
   rowvec <- 1L:nrow(X01)
 
-
-
   fitlist <- tapply(rowvec, gmemb, function(rind){      #list with nlm outputs
 
       if(length(rind) > 1L){
@@ -133,7 +128,7 @@
 
           ind.h   <- 0L:(length(beta.i)-1L)
           theta.h <- ind.h %*% t(theta)         #n. categories times theta
-          #!!!FIXME
+          
           term1 <- (theta.h + beta.i) * x01.i0  #category-person matrix
           t1.i  <- sum(colSums(term1))          #sum over categories and persons
           #print(t1.i)
@@ -193,8 +188,6 @@
     hessian[[i]]  <- fitlist[[i]]$hessian
   }
 
-
-
   if(interpolation){   #cubic spline interpolation for 0 and full raw scores
     x     <- rowSums(X, na.rm = TRUE)
     xlist <- split(x, gmemb)
@@ -241,9 +234,32 @@
                      rval
                    }  
                  }, xlist, thetapar, max.rs.NAgroups, NAgroups.min, NAgroups.max)
+    
+    pred.list_se <- Map(function(xx, yy, rs, NAmin, NAmax){   # Map(...)  is  mapply(..., SIMPLFY = FALSE)
+      y    <- tapply(yy, xx, function(xy){ xy[1] })
+      x    <- unique(sort(xx))
+      from <- ifelse(NAmin == 0, 0, min(x))
+      to   <- ifelse(NAmax == rs, rs, max(x))
+      if((length(x) > 3) || (length(y) > 3)){   #otherwise splinereg is not admissible
+        fm1 <- interpSpline(x,y)
+        if((from == 0) | (to == rs)){
+          pred.val <- unclass(predict(fm1, unique(c(from, x, to))))
+        } else {
+          list(x=unname(x),y=unname(y))   #MM2012-02-01
+        }
+      } else {
+        splineMessage <- TRUE   # so that the message is only printed once
+        rval <- list(x=unname(x),y=unname(y))   #MM2012-02-01
+        if(from == 0){  rval$x <- c(0, rval$x)
+        rval$y <- c(NA, rval$y) }
+        if(to == rs){  rval$x <- c(rval$x, rs)
+        rval$y <- c(rval$y, NA) }
+        rval
+      }  
+    }, xlist, se.theta, max.rs.NAgroups, NAgroups.min, NAgroups.max)
+    
     X.n <- object$X
-  #  if (any(sapply(pred.list,is.null)))  pred.list <- NULL    #no spline interpolation applicable   #MM2012-02-01
-
+ 
     if(splineMessage) message("Spline interpolation in some subgroups not performed!\n  Less than 4 different person parameters estimable!\n  Perhaps NAs in subgroup(s).")
   }
 
@@ -264,16 +280,7 @@
   #--------------- end expand, labeling ---------------------------
 
 
-
-
-  #---------------------- theta.table new ----------------------   ## MM2012-02-01 START
-  #thetavec <- unlist(thetapar)
-  #ind.orig <- as.vector(unlist(tapply(1:length(gmemb1), gmemb1, function(ind) {ind})))
-  #theta.orig <- tapply(thetavec, ind.orig, function(ii) return(ii))   #original order theta parameter
-  #theta.table <- data.frame(theta.orig, gmemb1)
-  #colnames(theta.table) <- c("Person Parameter","NAgroup")
-  #rownames(theta.table) <- rownames(X.ex)
-
+  #---------------------- theta.table new ----------------------   
   if(length(NAgroup_exclude) > 0L){
     selector <- gmemb.X %in% gmemb_reduced
   } else {
@@ -288,19 +295,24 @@
   }
 
   theta.table <- data.frame("Person Parameter" = rep(NA, nrow(object$X)),
+                            "Std.Error" = rep(NA, nrow(object$X)),
                             "NAgroup" = NA,
                             "Interpolated" = FALSE,
                             row.names=rownames(object$X),
                             check.names = FALSE)
-
+  
   theta.table[selector, "Person Parameter"] <- mapply(function(rs, NAgroup){
                                                  pred.list[[NAgroup]]$y[which(pred.list[[NAgroup]]$x == rs)]
                                                }, rowSums(object$X, na.rm=T)[selector], gmemb.X_final)
+  
+  theta.table[selector, "Std.Error"] <- mapply(function(rs, NAgroup){
+    pred.list_se[[NAgroup]]$y[which(pred.list_se[[NAgroup]]$x == rs)]
+  }, rowSums(object$X, na.rm=T)[selector], gmemb.X_final)
+  
   theta.table[selector, "NAgroup"] <- gmemb.X_final
                             
   if(length(pers.exe) > 0) theta.table[pers.exe,"Interpolated"] <- TRUE
-                                                                   ## MM2012-02-01 END
-  
+                                                                   
 
   result <- list(X = X.n, X01 = object$X01, X.ex = X.ex, W = object$W, model = object$model,
                  loglik = loglik, loglik.cml = object$loglik, npar = npar, iter = niter, betapar = object$betapar,
